package cn.com.infosec.crypto.engines;

import cn.com.infosec.crypto.AsymmetricBlockCipher;
import cn.com.infosec.crypto.CipherParameters;
import cn.com.infosec.crypto.params.ParametersWithRandom;
import cn.com.infosec.crypto.params.RSAKeyParameters;
import cn.com.infosec.crypto.params.RSAPrivateCrtKeyParameters;
import java.math.BigInteger;
import java.security.SecureRandom;

public class RSABlindedEngine implements AsymmetricBlockCipher {
   private static BigInteger ZERO = BigInteger.valueOf(0L);
   private RSACoreEngine core;
   private RSAKeyParameters key;
   private SecureRandom random;

   public RSABlindedEngine() {
      RSABlindedEngine var10000 = this;
      super();
      RSACoreEngine var1;
      var1 = new RSACoreEngine.<init>();
      var10000.core = var1;
   }

   private BigInteger calculateR(BigInteger m) {
      int m1;
      int var2 = (m1 = m.bitLength() - 1) / 2;
      m1 = (this.random.nextInt() & 255) * ((m1 - var2) / 255) + var2;
      BigInteger var4;
      var4 = new BigInteger.<init>(m1, this.random);

      while(var4.equals(ZERO)) {
         var4 = new BigInteger.<init>(m1, this.random);
      }

      return var4;
   }

   public void init(boolean forEncryption, CipherParameters param) {
      this.core.init(forEncryption, param);
      if (param instanceof ParametersWithRandom) {
         RSABlindedEngine var10000 = this;
         ParametersWithRandom var3;
         this.key = (RSAKeyParameters)(var3 = (ParametersWithRandom)param).getParameters();
         var10000.random = var3.getRandom();
      } else {
         this.key = (RSAKeyParameters)param;
         this.random = new SecureRandom();
      }

   }

   public int getInputBlockSize() {
      return this.core.getInputBlockSize();
   }

   public int getOutputBlockSize() {
      return this.core.getOutputBlockSize();
   }

   public byte[] processBlock(byte[] in, int inOff, int inLen) {
      RSAKeyParameters var4;
      if ((var4 = this.key) != null) {
         RSACoreEngine var10000;
         if (var4 instanceof RSAPrivateCrtKeyParameters) {
            RSAPrivateCrtKeyParameters var8;
            if ((var8 = (RSAPrivateCrtKeyParameters)var4).getPublicExponent() != null) {
               RSABlindedEngine var9 = this;
               RSABlindedEngine var10001 = this;
               RSABlindedEngine var10002 = this;
               BigInteger var5 = this.core.convertInput(in, inOff, inLen);
               BigInteger in1;
               BigInteger inOff1 = var10002.calculateR(in1 = var8.getModulus());
               var5 = var10001.core.processBlock(inOff1.modPow(var8.getPublicExponent(), in1).multiply(var5).mod(in1));
               return var9.core.convertOutput(var5.multiply(inOff1.modInverse(in1)).mod(in1));
            } else {
               var10000 = this.core;
               return var10000.convertOutput(var10000.processBlock(var10000.convertInput(in, inOff, inLen)));
            }
         } else {
            var10000 = this.core;
            return var10000.convertOutput(var10000.processBlock(var10000.convertInput(in, inOff, inLen)));
         }
      } else {
         throw new IllegalStateException("RSA engine not initialised");
      }
   }
}
